@@ -1,4 +1,3 @@
-import importlib.util
 import sys
 from pathlib import Path
 from typing import List, Sequence
@@ -13,7 +12,6 @@ from pipx.constants import (
     EXIT_CODE_OK,
     EXIT_CODE_REINSTALL_INVALID_PYTHON,
     EXIT_CODE_REINSTALL_VENV_NONEXISTENT,
-    PIPX_SHARED_LIBS,
     ExitCode,
 )
 from pipx.emojis import error, sleep
@@ -22,7 +20,12 @@ from pipx.venv import Venv, VenvContainer
 
 
 def reinstall(
-    *, venv_dir: Path, local_bin_dir: Path, python: str, verbose: bool
+    *,
+    venv_dir: Path,
+    local_bin_dir: Path,
+    local_man_dir: Path,
+    python: str,
+    verbose: bool,
 ) -> ExitCode:
     """Returns pipx exit code."""
     if not venv_dir.exists():
@@ -47,13 +50,7 @@ def reinstall(
     else:
         package_or_url = venv.main_package_name
 
-    if importlib.util.find_spec("pip") is None:
-        raise PipxError(
-            f"Can not find pip. You may encounter issues uninstalling packages. "
-            f"Remove {PIPX_SHARED_LIBS} and run 'pipx reinstall-all' to fix them."
-        )
-
-    uninstall(venv_dir, local_bin_dir, verbose)
+    uninstall(venv_dir, local_bin_dir, local_man_dir, verbose)
 
     # in case legacy original dir name
     venv_dir = venv_dir.with_name(canonicalize_name(venv_dir.name))
@@ -64,12 +61,15 @@ def reinstall(
         venv.main_package_name,
         package_or_url,
         local_bin_dir,
+        local_man_dir,
         python,
         venv.pipx_metadata.main_package.pip_args,
         venv.pipx_metadata.venv_args,
         verbose,
         force=True,
+        reinstall=True,
         include_dependencies=venv.pipx_metadata.main_package.include_dependencies,
+        preinstall_packages=[],
         suffix=venv.pipx_metadata.main_package.suffix,
     )
 
@@ -78,9 +78,7 @@ def reinstall(
         if injected_package.package_or_url is None:
             # This should never happen, but package_or_url is type
             #   Optional[str] so mypy thinks it could be None
-            raise PipxError(
-                f"Internal Error injecting package {injected_package} into {venv.name}"
-            )
+            raise PipxError(f"Internal Error injecting package {injected_package} into {venv.name}")
         inject_dep(
             venv_dir,
             injected_name,
@@ -99,6 +97,7 @@ def reinstall(
 def reinstall_all(
     venv_container: VenvContainer,
     local_bin_dir: Path,
+    local_man_dir: Path,
     python: str,
     verbose: bool,
     *,
@@ -115,6 +114,7 @@ def reinstall_all(
             package_exit = reinstall(
                 venv_dir=venv_dir,
                 local_bin_dir=local_bin_dir,
+                local_man_dir=local_man_dir,
                 python=python,
                 verbose=verbose,
             )
@@ -125,8 +125,6 @@ def reinstall_all(
             if package_exit != 0:
                 failed.append(venv_dir.name)
     if len(failed) > 0:
-        raise PipxError(
-            f"The following package(s) failed to reinstall: {', '.join(failed)}"
-        )
+        raise PipxError(f"The following package(s) failed to reinstall: {', '.join(failed)}")
     # Any failure to install will raise PipxError, otherwise success
     return EXIT_CODE_OK
