@@ -64,15 +64,11 @@ def rmdir(path: Path, safe_rm: bool = True) -> None:
     # move it to be deleted later if it still exists
     if path.is_dir():
         if safe_rm:
-            logger.warning(
-                f"Failed to delete {path}. Will move it to a temp folder to delete later."
-            )
+            logger.warning(f"Failed to delete {path}. Will move it to a temp folder to delete later.")
 
             path.rename(_get_trash_file(path))
         else:
-            logger.warning(
-                f"Failed to delete {path}. You may need to delete it manually."
-            )
+            logger.warning(f"Failed to delete {path}. You may need to delete it manually.")
 
 
 def mkdir(path: Path) -> None:
@@ -114,17 +110,19 @@ def run_pypackage_bin(bin_path: Path, args: List[str]) -> NoReturn:
 
 if WINDOWS:
 
-    def get_venv_paths(root: Path) -> Tuple[Path, Path]:
+    def get_venv_paths(root: Path) -> Tuple[Path, Path, Path]:
         bin_path = root / "Scripts" if not MINGW else root / "bin"
         python_path = bin_path / "python.exe"
-        return bin_path, python_path
+        man_path = root / "share" / "man"
+        return bin_path, python_path, man_path
 
 else:
 
-    def get_venv_paths(root: Path) -> Tuple[Path, Path]:
+    def get_venv_paths(root: Path) -> Tuple[Path, Path, Path]:
         bin_path = root / "bin"
         python_path = bin_path / "python"
-        return bin_path, python_path
+        man_path = root / "share" / "man"
+        return bin_path, python_path, man_path
 
 
 def get_site_packages(python: Path) -> Path:
@@ -180,6 +178,7 @@ def run_subprocess(
         stderr=subprocess.PIPE if capture_stderr else None,
         encoding="utf-8",
         universal_newlines=True,
+        check=False,
     )
 
     if capture_stdout and log_stdout:
@@ -191,18 +190,14 @@ def run_subprocess(
     return completed_process
 
 
-def subprocess_post_check(
-    completed_process: "subprocess.CompletedProcess[str]", raise_error: bool = True
-) -> None:
+def subprocess_post_check(completed_process: "subprocess.CompletedProcess[str]", raise_error: bool = True) -> None:
     if completed_process.returncode:
         if completed_process.stdout is not None:
             print(completed_process.stdout, file=sys.stdout, end="")
         if completed_process.stderr is not None:
             print(completed_process.stderr, file=sys.stderr, end="")
         if raise_error:
-            raise PipxError(
-                f"{' '.join([str(x) for x in completed_process.args])!r} failed"
-            )
+            raise PipxError(f"{' '.join([str(x) for x in completed_process.args])!r} failed")
         else:
             logger.info(f"{' '.join(completed_process.args)!r} failed")
 
@@ -295,16 +290,12 @@ def analyze_pip_output(pip_stdout: str, pip_stderr: str) -> None:
         failed_to_build_str = "\n    ".join(failed_build_stdout)
         plural_str = "s" if len(failed_build_stdout) > 1 else ""
         print("", file=sys.stderr)
-        logger.error(
-            f"pip failed to build package{plural_str}:\n    {failed_to_build_str}"
-        )
+        logger.error(f"pip failed to build package{plural_str}:\n    {failed_to_build_str}")
     elif failed_build_stderr:
         failed_to_build_str = "\n    ".join(failed_build_stderr)
         plural_str = "s" if len(failed_build_stderr) > 1 else ""
         print("", file=sys.stderr)
-        logger.error(
-            f"pip seemed to fail to build package{plural_str}:\n    {failed_to_build_str}"
-        )
+        logger.error(f"pip seemed to fail to build package{plural_str}:\n    {failed_to_build_str}")
     elif last_collecting_dep is not None:
         print("", file=sys.stderr)
         logger.error(f"pip seemed to fail to build package:\n    {last_collecting_dep}")
@@ -316,13 +307,9 @@ def analyze_pip_output(pip_stdout: str, pip_stderr: str) -> None:
 
         print_categories = [x.category for x in relevant_searches]
         relevants_saved_filtered = relevants_saved.copy()
-        while (len(print_categories) > 1) and (
-            len(relevants_saved_filtered) > max_relevant_errors
-        ):
+        while (len(print_categories) > 1) and (len(relevants_saved_filtered) > max_relevant_errors):
             print_categories.pop(-1)
-            relevants_saved_filtered = [
-                x for x in relevants_saved if x[1] in print_categories
-            ]
+            relevants_saved_filtered = [x for x in relevants_saved if x[1] in print_categories]
 
         for relevant_saved in relevants_saved_filtered:
             print(f"    {relevant_saved[0]}", file=sys.stderr)
@@ -336,9 +323,7 @@ def subprocess_post_check_handle_pip_error(
         # Save STDOUT and STDERR to file in pipx/logs/
         if pipx.constants.pipx_log_file is None:
             raise PipxError("Pipx internal error: No log_file present.")
-        pip_error_file = pipx.constants.pipx_log_file.parent / (
-            pipx.constants.pipx_log_file.stem + "_pip_errors.log"
-        )
+        pip_error_file = pipx.constants.pipx_log_file.parent / (pipx.constants.pipx_log_file.stem + "_pip_errors.log")
         with pip_error_file.open("w", encoding="utf-8") as pip_error_fh:
             print("PIP STDOUT", file=pip_error_fh)
             print("----------", file=pip_error_fh)
@@ -349,10 +334,7 @@ def subprocess_post_check_handle_pip_error(
             if completed_process.stderr is not None:
                 print(completed_process.stderr, file=pip_error_fh, end="")
 
-        logger.error(
-            "Fatal error from pip prevented installation. Full pip output in file:\n"
-            f"    {pip_error_file}"
-        )
+        logger.error("Fatal error from pip prevented installation. Full pip output in file:\n" f"    {pip_error_file}")
 
         analyze_pip_output(completed_process.stdout, completed_process.stderr)
 
@@ -374,12 +356,7 @@ def exec_app(
 
     if extra_python_paths is not None:
         env["PYTHONPATH"] = os.path.pathsep.join(
-            extra_python_paths
-            + (
-                os.getenv("PYTHONPATH", "").split(os.path.pathsep)
-                if os.getenv("PYTHONPATH")
-                else []
-            )
+            extra_python_paths + (os.getenv("PYTHONPATH", "").split(os.path.pathsep) if os.getenv("PYTHONPATH") else [])
         )
 
     # make sure we show cursor again before handing over control
@@ -396,6 +373,7 @@ def exec_app(
                 stderr=None,
                 encoding="utf-8",
                 universal_newlines=True,
+                check=False,
             ).returncode
         )
     else:
@@ -409,9 +387,7 @@ def full_package_description(package_name: str, package_spec: str) -> str:
         return f"{package_name} from spec {package_spec!r}"
 
 
-def pipx_wrap(
-    text: str, subsequent_indent: str = "", keep_newlines: bool = False
-) -> str:
+def pipx_wrap(text: str, subsequent_indent: str = "", keep_newlines: bool = False) -> str:
     """Dedent, strip, wrap to shell width. Don't break on hyphens, only spaces"""
     minimum_width = 40
     width = max(shutil.get_terminal_size((80, 40)).columns, minimum_width) - 2
